#
# spec file for package python-oslo.config
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global sname oslo.config
Name:           python-oslo.config
Version:        3.17.0
Release:        2.7
Summary:        OpenStack common configuration library
License:        Apache-2.0
Group:          Development/Languages
Url:            https://launchpad.net/%{sname}
Source0:        https://pypi.io/packages/source/o/%{sname}/%{sname}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-debtcollector >= 1.2.0
BuildRequires:  python-devel
BuildRequires:  python-fixtures >= 3.0.0
BuildRequires:  python-mock >= 2.0
BuildRequires:  python-netaddr >= 0.7.12
BuildRequires:  python-oslo.i18n >= 2.1.0
BuildRequires:  python-oslotest >= 1.10.0
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-python-subunit >= 0.0.18
BuildRequires:  python-rfc3986 >= 0.2.0
BuildRequires:  python-six >= 1.9.0
BuildRequires:  python-stevedore >= 1.16.0
BuildRequires:  python-testrepository >= 0.0.18
BuildRequires:  python-testscenarios >= 0.4
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-debtcollector >= 1.2.0
Requires:       python-netaddr >= 0.7.12
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-rfc3986 >= 0.2.0
Requires:       python-six >= 1.9.0
Requires:       python-stevedore >= 1.16.0
BuildArch:      noarch

%description
The Oslo project intends to produce a python library containing
infrastructure code shared by OpenStack projects. The APIs provided
by the project should be high quality, stable, consistent and generally
useful.

The oslo-config library is a command line and configuration file
parsing library from the Oslo project.

%package doc
Summary:        Documentation for OpenStack common configuration library
Group:          Development/Languages
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx >= 2.5.0

%description doc
Documentation for the oslo-config library.

%prep
%setup -q -n %{sname}-%{version}

%build
%{py2_build}

%{__python2} setup.py build_sphinx
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py2_install}

%check
%{__python2} setup.py testr

%files
%doc README.rst
%license LICENSE
%{_bindir}/oslo-config-generator
%{python2_sitelib}/oslo_config
%{python2_sitelib}/*.egg-info

%files doc
%doc doc/build/html
%license LICENSE

%changelog
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 3.17.0
  * Add set_override method test with ListOpt
  * Fix: default value of prog should remove extension
  * Updated from global requirements
  * Add Port type to allow configuration of a list of tcp/ip ports
  * Advanced Option
* Mon Aug  8 2016 dmueller@suse.com
- update to 3.14.0:
  * disable lazy translation in sphinx extension
  * Trivial: adjust import order to fit the import order guideline
  * Make error message more clear
  * Add min and max values to Float type and Opt
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Add max_length to URIOpt
  * Remove discover from test-requirements
  * update docs for sphinxconfiggen
  * Add URIOpt to doced option types
* Fri Jul 29 2016 dmueller@suse.com
- update to 3.13.0:
  * Add Python 3.5 classifier and venv
  * Enabling your project for mutable-config
  * Add namespace to _list_opts() in test
  * decode subprocess output so doc build works on python3
  * Updated from global requirements
* Mon Jul  4 2016 tbechtold@suse.com
- update to 3.12.0:
  * Add URIOpt
  * Add support for a deprecated version
  * Updated from global requirements
  * Support template substitution of DictOpt
  * fixture: Provide parameter enforce_type for method config
  * Fix typo: 'olso' to 'oslo'
  * Return [] for .config_dirs when config files are not parsed
  * generator: format string default value for List type properly
  * Updated from global requirements
  * Required Option
  * Updated from global requirements
  * Make sure ConfigType is an abstract class
  * Added i18n formatting to log messages
  * Remove duplicated code in method test_equal of HostnameTypeTests
  * Incorrect group name when deprecated_group is not specified
  * Handle some native python types in config generation
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- Switch to.spec from rpm-packaging upstream project
* Sun Feb 28 2016 dmueller@suse.com
- update to 3.9.0:
  * remove redundant call to set explicit target
  * clear the cache before mutating the config files
  * Updated from global requirements
  * Add None-check to find_file
  * add support for mutable options in the config generator
  * add unreleased page to release notes build
  * add a release note mentioning our use of reno
  * Add reno for release notes management
  * Hooks around mutate_config_files
  * Add hostname config type
  * Add config_dirs property with a list of directories
  * Fix wrong check with non-None value when format group
  * add generator hook for apps to update option defaults
  * Updated from global requirements
  * refactor generator._list_opts for further enhancement
  * Add debtcollector as requirement
  * always show coverage output from tests
  * handle group objects in sphinxext
  * refactor sphinxext and add unit tests
  * have show-options load the generator config file
  * support multiple namespaces in sphinxext
  * refactor sphinxext to make reformatting easier
  * refactor generator closures to private methods
  * Updated from global requirements
  * remove specially attribute handling from _Namespace
  * Fix unrecognized subparser args
  * Add test for BoolOpt with no default
  * Fix bandit entry in tox.ini
  * Removal of bandit.yaml
  * Log mutated options at INFO
  * Fix version 'mutable' was added
  * Fix PortOpt versionchanged
  * treat option group names as section headers when documenting them
  * Fix MultiConfigParser removal version
  * Retain correct order of defined config options
* Thu Feb 11 2016 dmueller@suse.com
- update to 3.4.0:
  * Do not fail on certain config option help strings
  * Updated from global requirements
  * enhance sphinx integration to allow links to option definitions
  * Remove argparse from requirements
  * Updated from global requirements
  * replace reference to default value in option help text in docs
  * add built-in options to auto-generated documentation
  * register the built-in options for the config generator to find
  * Add reST work label for configuration options
  * Allow port number with 0
  * Replace deprecated library function os.popen() with subprocess
  * Fix can't generate config sample with non-None value
  * Fixed deprecated_for_removal warning generation
  * Module index grouping
  * Docs class links
  * generator: ignore doubles
  * Numerous corrections to the docstrings
  * Make oslo-config-generator fail gracefully when no arguments
  * Replace assertEqual(*, None) with assertIsNone in tests
  * Python 3 deprecated the logger.warn method in favor of warning
  * Replace assertEqual(None,*) with assertIsNone(*)
  * Cleanly handle an undefined attribute reference
  * Replace assertEqual with assertTrue and assertFalse
  * assertIsNone(val) instead of assertEqual(None,val)
* Fri Jan  8 2016 bwiedemann@suse.com
- Update to version 3.2.0
  * Capitalize IP
  * Add support for a deprecation reason
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Make PortOpt accept choices parameter
  * Test equality of types.String choices as a set
  * Add new parameter `choices` to Integer type
  * [fix-compat] Tolerate non-string defaults in String type
  * [fix-compat] Support older use case for Opt type
  * Handle None section name in MultiOptConfigParser#get
  * Allow method set_override with parameter override=None for all types
  * Move type formatting from generator to type
  * Allow naming of custom types
  * Remove 'raise' in _get
  * Remove python 2.6 support
  * Add DEFAULT group in NoSuchOptError when group=None
* Fri Nov 20 2015 bwiedemann@suse.com
- update to 2.7.0:
  * Add max length check to StrOpt
  * Fix StrOpt to allow setting quotes and regex
  * Improve default type checking
  * Use versionadded and versionchanged in doc
  * update doc to use new type PortOpt
  * Fix versionchanged
  * Raise exception when wrong type is used as default
  * Add PortOpt for integer with range 1 to 65535
  * Fix typos in cfg.py
  * Case insensitiveness when comparing choices values
  * Add missing tests and generator code for IPOpt
  * Fix coverage configuration and execution
  * Add item_type and bounds to ListOpt
  * Fix bad exception for StrOpt with invalid choice value
  * fix literal rendering in dictionary options docs
  * Fix home-page value in setup.cfg with Oslo wiki
  * docs - Set pbr 'warnerrors' option for doc build
  * Include changelog/history in docs
  * Correct the comment of __call__ method
  * Demonstrate that MultiStr values from multiple sources are merged
  * Make Integer type class honor zero for min/max
* Fri Aug 28 2015 tbechtold@suse.com
- Fix doc build
* Thu Aug 27 2015 tbechtold@suse.com
- update to 2.3.0:
  * Add sphinx extension to embed pretty descriptions of options
  * Add sphinx extension to build sample config
  * Updated from global requirements
  * Updated from global requirements
  * preserve preformatted help text
* Fri Jul 31 2015 tbechtold@suse.com
- update to 2.1.0:
  * Updated from global requirements
  * Add regex validation to String type
  * Add enforce_type option when setting an override
  * Updated from global requirements
  * Add *.egg* to .gitignore
  * Updated from global requirements
  * Remove oslo namespace package
  * Fix use of mock for 1.1.0
  * Updated from global requirements
  * Expose min and max to IntOpt
  * Don't convert ValueError into NoSuchOptError in ConfigOpts
  * Updated from global requirements
  * Add FAQ entry for why we do not treat config options as API
  * Add set_default() method to fixture
  * fix fixture tests for fixtures 1.3.x
  * Add tox target to find missing requirements
  * Do not use oslo namespace for oslo.i18n lib
  * Fixes example for cfg
  * Updated from global requirements
  * Fix sorting of optional arguments
  * Switch badges from 'pypip.in' to 'shields.io'
  * Updated from global requirements
  * Fix sorting issue in python 3
  * Fix typo in Opt class doc string
- Adjust Requires
* Fri Jul 31 2015 tbechtold@suse.com
- Unify spec file #2
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file
* Wed Jun 10 2015 tbechtold@suse.com
- update to 1.12.1:
  * Fix sorting issue in python 3
* Mon Jun  8 2015 tbechtold@suse.com
- update to 1.12.0:
  * Remove pbr requirement
  * Document properties as properties
  * make registering a cli opt on a filter object work
  * Remove outdated release notes
  * cfg: support interpolation of config option from other groups
  * Advertise support for Python3.4 / Remove support for 3.3
  * Do not sync run_cross_tests.sh
  * Updated from global requirements
  * Fix issue when generating code with cfg.OptGroup
  * Option name missing from ConfigFileValueError
  * Remove run_cross_tests.sh
  * Enforce alphabetic loading order for --config-dir contents
- Remove python-pbr from Requires
* Thu Apr 30 2015 dmueller@suse.com
- update to 1.11.0:
  * Uncap library requirements for liberty
  * Added Raw Value Loading to Test Fixture
  * Add pypi download + version badges
  * Update hacking to kilo level
  * Add deprecated_for_removal support to the config generator
  * Generate docs for constructor
  * Fix doc build warning
  * Updated from global requirements
* Mon Mar 30 2015 tbechtold@suse.com
- update to 1.9.3:
  * Switch to non-namespaced module imports
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.9.2:
  * print better message when choices has an empty string
  * None in config choices breaks oslo-config-generator
  * Generate help text indicating possible values
  * fix bug link in readme
  * Add ability to deprecate opts for removal
  * Typo in StrOpt docstring: Integer to String
  * Add exception handling for entry points
* Tue Feb 24 2015 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Log a warning when deprecated opts are used
  * Do not import our namespace package
  * Fixes deprecation warning for oslo.config in cfg.py
  * Clear up MultiStrOpt and related documentation
  * Add a list_all_sections method to ConfigOpts
  * Better check for integer range to account for 0
  * Reword DeprecatedOpt docstring
  * Support i18n messages in config generator
  * Fix of wrong cli opts unregistration
- Cleanup BuildRequires. SLES 11 is no longer a build target
- Add python-oslo.i18n as BuildRequires for tests
- Disable testrun for now
* Wed Jan 14 2015 tbechtold@suse.com
- Add python_requires to _service
- Update Requires version according to requirements.txt
* Thu Jan  8 2015 tbechtold@suse.com
- update to version 1.6.0:
  * Set the version string
  * Stop sorting options on output
  * Move files out of the namespace package
  * Workflow documentation is now in infra-manual
  * Fix wrong order of positional args in cli
  * add tests coverage for an oslo.messaging use case
  * Refactored help string generation
  * Updated from global requirements
  * Updated from global requirements
  * Fix class constant indentation
  * Updated from global requirements
  * Activate pep8 check that _ is imported
  * Updated from global requirements
  * Updated from global requirements
  * Add pbr to installation requirements
  * Updated from global requirements
  * Add some guidance for group names
  * delay formatting debug log message
  * Check config default value is correct type
  * Report permission denied when parsing config
  * Fix docs example using generator config files
  * Updated from global requirements
  * do not use colons in section titles
  * Stop using intersphinx
- Adjust Requires according to requirements.txt
- Adjust BuildRequires according to test-requirements.txt
- Install oslo_config into sitelib
* Sun Sep 21 2014 tbechtold@suse.com
- update to version 1.4.0:
  * Looks for variable subtitution in the same group
- Fix version Requires for python-netaddr
- Adjust BuildRequires according to test-requirements.txt
* Fri Sep 12 2014 dmueller@suse.com
- update to 1.4.0.0a4:
  * Updated from global requirements
  * Log a fixed length string of asterisks for obfuscation
  * Added link to bug tracker and documentation in oslo.config readme
  * Bump hacking to version 0.9.2
* Tue Jul 29 2014 dmueller@suse.com
- update to 1.4.0a3:
  * Changes imports order to pass H305, enables check
  * generator: tweak how MultiStrOpt defaults are handled
  * Add release notes for 1.3.0 and 1.4.0.0a1/2
  * Hook up config fixture docs
  * Hook IPOpt class into the docs
  * Replaced 'e.g.' with 'for example'
  * Add cfgfilter.ConfigFilter
  * generator: remove the default sanitizer feature
  * cfg,generator: add Opt.sample_default attribute
  * generator: refactor MultiStrOpt handling
  * Fix flaws in methods' docstring
  * Introduce Opts for IP addresses
  * Refactors _Namespace to make the code clearer
  * Add oslo-config-generator
  * Add CLI option support to config fixture
  * Updated from global requirements
  * Remove print statement from types.Dict
  * Add warning about interpolating values from groups
  * Add more tests for positional CLI opts
  * Add test case for hyphenated option names
  * Fixes an issue validating max integer values
  * Bump hacking to 0.9.x series
  * Updated from global requirements
  * Add a doc sample for how to use the required field
  * log: string format arguments changed to function parameters
  * Fix deprecated_opts for cli options
  * Reject option names prefixed with '_'
  * Graduate config fixture
  * Updated from global requirements
  * Fix test_version on Python 3.4
  * Add section titles and fix markup of docstring
  * Avoid using too generic names in _Namespace
  * Import run_cross_tests.sh from oslo-incubator
  * Move py33 env before py2x
* Fri Jun 27 2014 dmueller@suse.com
- go back to released version (1.3.0)
* Fri Jun 20 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.29.ge0172be:
  * Updated from global requirements
  * Add more tests for positional CLI opts
* Thu Jun 19 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.26.g582e1a3:
  * Remove print statement from types.Dict
  * Add test case for hyphenated option names
* Sun Jun 15 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.22.g1746fd2:
  * Fixes an issue validating max integer values
  * Bump hacking to 0.9.x series
* Wed Jun 11 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.19.g6c283cd:
  * Updated from global requirements
  * Add a doc sample for how to use the required field
* Tue May 27 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.16.g8b4bf0f:
  * log: string format arguments changed to function parameters
* Sat May 10 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.15.g78c2bc9:
  * Fix deprecated_opts for cli options
* Thu May  8 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.13.gbdb0814:
  * Updated from global requirements
* Wed May  7 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.11.ga4bb2e4:
  * Add section titles and fix markup of docstring
* Tue May  6 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.9.g7240ad9:
  * Reject option names prefixed with '_'
  * Fix docstring for _Namespace._get_cli_value
* Sun May  4 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.5.gb3ed1ac:
  * Graduate config fixture
* Sat Apr 26 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.4.g0a66c27:
  * Fix test_version on Python 3.4
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.3.g78225a5:
  * Avoid using too generic names in _Namespace
* Sat Apr  5 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.2.g4b8b206:
  * Import run_cross_tests.sh from oslo-incubator
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0.1.g1dc9e67:
  * Move py33 env before py2x
  1.3.0
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.40.gb347519:
  * Include the 'meta' trove classifiers for python versions
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.39.ga5faf6b:
  * Do substitution on overrides and defaults too
  * Follow style guide for help strings
* Mon Mar  3 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.35.gc577365:
  * Updated from global requirements
  * Convert to oslo.test
  * Add py33 trove classifier
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.31.g076d828:
  * Fix a whitespace in a comment
* Sun Feb 23 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.30.g482e276:
  * Fix docstring of parsing order
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.28.g4c5c1ea:
  * Remove extraneous vim configuration comments
* Sun Feb 16 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-Switch-over-to-oslosphinx.patch dropped (merged upstream)
* Sun Feb 16 2014 cloud-devel@suse.de
- Update to version oslo.config-1.3.0a0.26.g13de959:
  * Switch over to oslosphinx
* Fri Feb 14 2014 speilicke@suse.com
- Run testr directly
* Thu Feb 13 2014 dmueller@suse.com
- added patches:
  * 0001-Switch-over-to-oslosphinx.patch
* Tue Feb 11 2014 speilicke@suse.com
- Update to version oslo.config-1.3.0a0.25.g2f98541:
  * Fix misspellings in oslo.config
  * Support building wheels (PEP-427)
  * Add Style Guide for help of config options
  * Add docs for types
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
- Use argparse only on SLE
* Wed Jan 29 2014 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.18.g16541c5:
  + Throw exception if --config-dir doesn't exist
* Tue Jan 28 2014 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.16.g3b8197e:
  + Remove copyright from empty files
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.14.ge6bcb78:
  + Implemented support for custom opt types
* Sun Jan 12 2014 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.12.g0c3a643:
  + Fix for parsing error with Dollar Sign ($) in values
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.10.g9972082:
  + Fix spelling errors in docstrings and comments
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.8.g47b49e8:
  + Utilizes assertIsNone and assertIsNotNone
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.7.g74cd448:
  + Added support of operator '=='
* Fri Dec 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.6.g73d60b3:
  + Updated from global requirements
* Mon Nov 18 2013 speilicke@suse.com
- Add python-argparse test requirement
* Fri Nov 15 2013 speilicke@suse.com
- Run testsuite during build (%%check section) and obsolete the test
  package. An overall simplification of the test process
- Needs a funky hack to circumvent PTH files shipped by oslo components
* Fri Nov  8 2013 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.5.g03930e3:
  + Updated from global requirements
* Sat Nov  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.3.0a0.4.g4d08ec6:
  + Fix to make ConfigOpts no longer obscure IOErrors
* Fri Oct 25 2013 dmueller@suse.com
- switch back to master tarball
* Fri Sep 27 2013 speilicke@suse.com
- Fix service URL
* Thu Sep 26 2013 dmueller@suse.com
- update to 1.2.1:
  * 1223667_: Fix DictOpt to split only the first colon
  * 1228995_: Disallow duplicate keys in DictOpt
  * Explicit version removed from setup.cfg
  * Dependency version updates
  * Add auto-create support for OptGroup instances (see review 41865_)
  * Publish full API docs to docs.openstack.org_
  * Finished Python 3 support
  * 1196601_: Raise an exception if print_help() is called before __call__
  * Fix DeprecatedOpt equality test
  * Use oslo.sphinx
* Mon Sep  2 2013 dmueller@suse.com
- update to 1.2.0.a4
* Thu Jul 18 2013 berendt@b1-systems.de
- added missing requirement python-argparse
* Sat Jul 13 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.0.a2:
  + Use oslo.sphinx and remove local copy of doc theme
  + Hook docstrings into the published docs
* Tue Jul  2 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.0.a35:
  + Add release notes for 1.2.0a3
* Sat Jun 29 2013 opensuse-cloud@opensuse.org
- Update to version 1.2.0.a34:
  + Ensure namespace package is installed.
* Thu Jun 27 2013 speilicke@suse.com
- Only depend on python-discover on SLE, it's a Python-2.6 feature
  backport
* Thu Jun 13 2013 dmueller@suse.com
- update test/main requires
* Wed Jun 12 2013 dmueller@suse.com
- fix tarball location
- merge in all the changes from the last 6 weeks
* Wed Jun 12 2013 dmueller@suse.com
- fix requires of test package
* Thu Apr  4 2013 dmueller@suse.com
- provide/obsolete python-oslo-config and its subpackages
* Mon Mar 18 2013 speilicke@suse.com
- Drop +git.$TIMESTAMP.$COMMITHASH version suffix
* Sun Mar 17 2013 cloud-devel@suse.de
- Update to version 1.2.0.a3+git.1363479216.91155c8:
  + Correct some typos in docstrings in cfg.py.
  + Copyright rename LLC to Foundation
  + Open 1.2.x development
  + Add Environment::OpenStack classifier
  + Fix copyright - from LLC to Foundation
* Mon Mar 11 2013 dmueller@suse.com
- rename package to python-oslo.config
- Update to version 1.1.0.a3+git.1362996413.6dca669:
  + Explicitly set ConfigOpts._args to sys.argv[1:]
  + Switch to semantic versioning
  + Change the name of the project to oslo.config
* Tue Feb 26 2013 iartarisi@suse.com
- remove unneeded patch for oslo/__init__.py, the namespace is
  declared in setup.py
* Fri Feb 22 2013 saschpe@suse.de
- BuildRequire openstack-suse-macros instead of openstack-macros
* Thu Feb 21 2013 iartarisi@suse.com
- remove testtool dependency; we can run the tests without it
* Wed Feb 20 2013 iartarisi@suse.com
- set BuildArch: noarch for newer distros
* Wed Feb 20 2013 iartarisi@suse.com
- initial version
